<?php

/**
 * @file
 * Helper functions for installation
 */

/**
 * Install a cck type from a file.
 */
function _sport_install_cck($path, $name) {
  $filename = $name . '.cck';
  
  $cck_content = file_get_contents($path . '/' . $filename);

  // Make sure all the field type modules are enabled
  $matches = array();
  preg_match_all("#module' => '([^']+)'#", $cck_content, $matches);
  $module_names = array_unique($matches[1]);
  if (preg_match('#content\[\'groups\'\]#', $cck_content)) {
    $module_names[] = 'fieldgroup';
  }
  $module_names[] = 'content';
  module_enable($module_names);

  // Load views for nodereferences
  module_enable(array('views'));
  views_include('view');
  views_discover_default_views();
  
  $form_state['values']['type_name'] = '<create>';
  $form_state['values']['macro'] = $cck_content;

  module_enable(array('content_copy'));
  drupal_execute("content_copy_import_form", $form_state);
}

/**
 * Install a cck type from a file.
 */
function _sport_install_cck_field($path, $name, $type) {
  $filename = $name . '.field';

  $form_state['values']['type_name'] = $type;
  $form_state['values']['macro'] = file_get_contents($path . '/' . $filename);

  module_enable(array('content_copy'));
  drupal_execute("content_copy_import_form", $form_state);
}


/**
 * Check if a cck type is installed correctly
 */
function _sport_check_cck_installation($path, $name, &$requirements) {
  // Ensure translations don't break at install time
  $t = get_t();

  $filename = $name . '.cck';
  $cck_content = file_get_contents($path . '/' . $filename);
  
  eval($cck_content);
  
  // check type
  $type_name = $content['type']['type'];
  $type = node_get_types('type', $type_name);
  
  if (!$type) {
    $requirements[$name] = array(
      'title' => $t('Content type %type', array('%type' => $content['type']['name'])),
      'value' => $t('Missing'),
      'severity' => REQUIREMENT_ERROR,
      'description' => $t('The content type %type is not installed', array('%type' => $content['type']['name'])),
    );
  }
  else {
    // check fields
    $fields = content_fields(NULL, $type_name);
    foreach($content['fields'] as $field) {
      $field_name = $field['field_name'];
      if (!isset($fields[$field_name])) {
        $requirements[$name . '_' . $field_name] = array(
          'title' => $t('Content type %type', array('%type' => $content['type']['name'])),
          'value' => $t('Missing field %field', array('%field' => $field['label'])),
          'severity' => REQUIREMENT_ERROR,
          'description' => $t('The content type %type is missing the field %field', array('%type' => $content['type']['name'], '%field' => $field['label'])),
        );
      }
    }
  }
}

/**
 * Disable the post information for the specified node type.
 */
function _sport_disable_post_information($type) {
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_' . $type] = FALSE;
  variable_set('theme_settings', $theme_settings);
}

/**
 * Set the pathauto pattern for a node type.
 */
function _sport_set_pathauto_pattern_for_type($type, $path_pattern) {
  variable_set('pathauto_node_'. $type .'_pattern', $path_pattern);
}

/**
 * Set the page_title pattern for a node type.
 */
function _sport_set_page_title_for_type($type, $path_pattern) {
  variable_set('page_title_type_'. $type, $path_pattern);
}

/**
 * Create an imagecache preset.
 */
function _sport_create_imagecache_preset($name, $width, $height) {
  module_enable(array('imagecache'));
  $presetid = db_result(db_query("SELECT presetid FROM {imagecache_preset} WHERE presetname='%s'", $name));
  if (!$presetid) {
    db_query("INSERT INTO {imagecache_preset} (presetname) VALUES ('%s')", $name);
    $presetid = db_result(db_query("SELECT presetid FROM {imagecache_preset} WHERE presetname='%s'", $name));
    db_query("INSERT INTO {imagecache_action} (presetid, action, data) VALUES (%d, '%s', '%s')",
      $presetid,
      'imagecache_scale', 
      serialize(array(
          'width' => $width,
          'height' => $height,
          'upscale' => 0,
        )
      )
    );
  }
  imagecache_presets(TRUE);
}

/**
 * Import a node using the 'node_export' module.
 */
function _sport_import_node($path, $name) {
  require_once(drupal_get_path('module', 'node_export') . '/node_export.pages.inc');
	$filename = $name . '.node';
  $file_content = file_get_contents($path . '/' . $filename);
  $import = node_export_node_decode($file_content);
  if (!is_array($import)) {
  	$nodes = array($import);
  }
  else {
  	$nodes = $import;
  }
  foreach ($nodes as $node) {
    node_export_node_save($node);
  }
}

/**
 * Grant permissions for anynomous user.
 */
function _sport_grant_anonymous($permissions) {
  // TODO: use of a defined constant would be nice
	_sport_grant_permissions(1, $permissions);
}

/**
 * Grant permissions for authenticated user.
 */
function _sport_grant_authenticated($permissions) {
  // TODO: use of a defined constant would be nice
  _sport_grant_permissions(2, $permissions);
}

/**
 * Grant permissions.
 */
function _sport_grant_permissions($role_id, $permissions) {
  $result = db_query("SELECT p.perm FROM {role} r JOIN {permission} p ON r.rid=p.rid WHERE r.rid = %d", $role_id);
  $previous_permissions = array();
  while ($row = db_fetch_object($result)) {
    $previous_permissions += explode(', ', $row->perm);
  }
  $permissions = array_unique(array_merge($previous_permissions, $permissions));
  
  db_query('DELETE FROM {permission} WHERE rid = %d', $role_id);
  db_query("INSERT INTO {permission} (rid, perm) VALUES (%d, '%s')", $role_id, implode(', ', $permissions));
}

/**
 * Set module weight
 */
function _sport_set_module_weight($module, $weight) {
  db_query("UPDATE {system} SET weight = %d WHERE name = '%s'", $weight, $module);
}

